import setuptools
import os.path
from distutils.core import  setup


packages = ['froxiaofeidriver']

setup(name='froxiaofeidriver',version='2.7.9',author='feipip', packages=packages, package_dir={'requests': 'requests'},)